#!/bin/sh
#
# source: http://ftp.gnome.org/pub/gnome/sources/gnome-settings-daemon/2.30/gnome-settings-daemon-2.30.1.tar.bz2
#
# maintainer: (package seek a maintainers)
#

#------------------Set Some Variables

buildir=$(pwd)
soft="gnome-settings-daemon"
softversion="2.30.1"
packageversion="66.1"
arch="i486"
cpu="i686"
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest

cd $src

chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --mandir=/usr/man \
    --disable-static \
    --disable-schemas-install \
    --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"

make -j2
make install DESTDIR=$dest

#------------------- gconf stuff

export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
        gconftool-2 --makefile-install-rule $schema
     done
# Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
fi

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS ChangeLog COPYING INSTALL MAINTAINERS NEWS README \
$dest/usr/doc/$soft-$softversion

( cd $dest/etc/xdg/autostart
sed -i 's/OnlyShowIn=GNOME;/OnlyShowIn=GNOME;XFCE;/g' gnome-settings-daemon.desktop
)
#------------------ make a slack-desc file

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                     |-----handy-ruler-------------------------------------------------|
gnome-settings-daemon: gnome-settings-daemon - The GNOME settings daemon
gnome-settings-daemon:
gnome-settings-daemon: gnome-settings daemon runs in the background of a GNOME session
gnome-settings-daemon: and applies the correct user settings, like icon themes, colours
gnome-settings-daemon: etc.
gnome-settings-daemon:
gnome-settings-daemon:
gnome-settings-daemon:
gnome-settings-daemon:
gnome-settings-daemon:
gnome-settings-daemon:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/

cd $dest
makepkg -l y -c n $dest.txz
cd $buildir
md5sum $package.txz > $package.md5